# ec_ecology_toolbox

[![C/C++ CI](https://github.com/emilydolson/ec_ecology_toolbox/actions/workflows/c-cpp.yml/badge.svg)](https://github.com/emilydolson/ec_ecology_toolbox/actions/workflows/c-cpp.yml) [![codecov](https://codecov.io/gh/emilydolson/ec_ecology_toolbox/branch/master/graph/badge.svg)](https://codecov.io/gh/emilydolson/ec_ecology_toolbox)
